marktools
=========

.. automodule:: abjad.tools.marktools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.marktools.Annotation.Annotation.Annotation
      ~abjad.tools.marktools.Articulation.Articulation.Articulation
      ~abjad.tools.marktools.BarLine.BarLine.BarLine
      ~abjad.tools.marktools.BendAfter.BendAfter.BendAfter
      ~abjad.tools.marktools.LilyPondCommandMark.LilyPondCommandMark.LilyPondCommandMark
      ~abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment
      ~abjad.tools.marktools.Mark.Mark.Mark
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo
